#!/bin/sh 
### MODIFIED for matching Virtualbox problem
NAME=entware

PKG_PATH=/usr/local/AppCentral/${NAME}

. /etc/script/lib/nas-functions.sh

echo " start_stop.sh" >> /tmp/${NAME}_start.log

if [ ! -e $PKG_PATH/CONTROL/env.sh ]; then
    echo "Can't find $PKG_PATH/CONTROL/env.sh"
    exit 1
fi

source $PKG_PATH/CONTROL/env.sh

. /lib/lsb/init-functions

create_path(){
	if [ ! -e ${PKG_PATH}/opt ] ; then
		mkdir ${PKG_PATH}/opt
	fi
	for F in bacula  bin  downloads  eggdrop  etc  include  lib  libexec  sbin  share  tmp  usr  var root home html
	do
		if [ ! -e ${PKG_PATH}/opt/${F} ] ; then
			mkdir ${PKG_PATH}/opt/${F}
		fi
		if [ -L /opt/${F} ] ; then
			rm -f /opt/${F}
		fi
		ln -s ${PKG_PATH}/opt/${F} /opt/
	done
	if [ ! -e ${PKG_PATH}/opt/var/lock ] ; then
		mkdir -p ${PKG_PATH}/opt/var/lock
	fi
	if [ ! -e ${PKG_PATH}/opt/lib/opkg ] ; then
		mkdir -p ${PKG_PATH}/opt/lib/opkg
	fi
}

delete_path(){
	for F in bacula  bin  downloads  eggdrop  etc  include  lib  libexec  sbin  share  tmp  usr  var root home html
	do
		if [ -L /opt/${F} ] ; then
	             rm -f /opt/${F}
        	fi
	done
}
entware_install(){
	unset LD_LIBRARY_PATH
	unset LD_PRELOAD
	echo "Info: Opkg package manager deployment..."
	source $PKG_PATH/CONTROL/install_env.sh
	wget $URL/opkg -O /opt/bin/opkg
	chmod 755 /opt/bin/opkg
	wget $URL/opkg.conf -O /opt/etc/opkg.conf
	wget $URL/ld-2.27.so -O /opt/lib/ld-2.27.so
	wget $URL/libc-2.27.so -O /opt/lib/libc-2.27.so
	wget $URL/libgcc_s.so.1 -O /opt/lib/libgcc_s.so.1
	wget $URL/libpthread-2.27.so -O /opt/lib/libpthread-2.27.so
	cd /opt/lib
	chmod 755 ld-2.27.so
	ln -s ld-2.27.so $DLOADER
	ln -s libc-2.27.so libc.so.6
	ln -s libpthread-2.27.so libpthread.so.0
	if [ "$DLOADER" = "ld-linux.so.3" ] ; then
		echo "option force_space" >> /opt/etc/opkg.conf
	fi
	echo "Info: Basic packages installation..."
	/opt/bin/opkg update
	/opt/bin/opkg install entware-opt

	# Fix for multiuser environment
	chmod 777 /opt/tmp
	# now try create symlinks - it is a std installation
	if [ -f /etc/passwd ]
	then
	    ln -sf /etc/passwd /opt/etc/passwd
	else
	    cp /opt/etc/passwd.1 /opt/etc/passwd
	fi
	if [ -f /etc/group ]
	then
	    ln -sf /etc/group /opt/etc/group
	else
	    cp /opt/etc/group.1 /opt/etc/group
	fi
	if [ -f /etc/shells ]
	then
	    ln -sf /etc/shells /opt/etc/shells
	else
	    cp /opt/etc/shells.1 /opt/etc/shells
	fi
	if [ -f /etc/shadow ]
	then
	    ln -sf /etc/shadow /opt/etc/shadow
	fi
	if [ -f /etc/gshadow ]
	then
	    ln -sf /etc/gshadow /opt/etc/gshadow
	fi
	if [ -f /etc/localtime ]
	then
	    ln -sf /etc/localtime /opt/etc/localtime
	fi
	rm -f ${PKG_PATH}/.install-todo
}

start_daemon () {	
	/bin/grep source /etc/profile | grep -v Apps | grep -q opt 
	if [ $? -eq 0 ] ; then
		# already sourced
		echo "/etc/profile is updated ... "
	else 
		echo "source /opt/etc/profile" >> /etc/profile
	fi 
	/opt/etc/init.d/rc.unslung start
}

stop_daemon () {
	/opt/etc/init.d/rc.unslung stop
	sleep 2 
	/bin/sed -i '/source \/opt\/etc\/profile/d' /etc/profile
	/bin/sync
	sleep 1
	delete_path
}

case "$1" in
    start)
        log_daemon_msg "Starting daemon" "$NAME"
	create_path
	### test if already installed
	if [ -e ${PKG_PATH}/.install-todo ] ; then
		entware_install
	fi
        start_daemon
        log_end_msg 0
        ;;
    stop)
        log_daemon_msg "Stopping daemon" "$NAME"
        stop_daemon
        log_end_msg 0
        ;;
    
    restart)
	log_daemon_msg "Stopping daemon" "$NAME"
	stop_daemon
	sleep 2
	log_daemon_msg "Starting daemon" "$NAME"
        start_daemon
        log_end_msg 0
        ;;
   install_again)
	rm -f ${PKG_PATH}/.install-todo
	entware_install
   	;;
   update_packages)
   	/opt/bin/opkg update
	/opt/bin/opkg upgrade
	;;
    *)
        echo "Usage: /etc/init.d/$NAME {start|stop|restart}"
	echo "Usage: /etc/init.d/$NAME {install_again} ONLY in case of Internet problem during normal install"
	echo "Usage: /etc/init.d/$NAME {update_packages} IF entware is started like opkg update ; opkg upgrade"
        exit 2
        ;;
esac

exit 0

